@@ -21,6 +21,7 @@ License: BSD (see LICENSE.md for details).
 
 from markdown.test_tools import TestCase
 from markdown.extensions.codehilite import CodeHiliteExtension, CodeHilite
+import os
 
 try:
     import pygments  # noqa
@@ -28,10 +29,19 @@ try:
 except ImportError:
     has_pygments = False
 
+# The version required by the tests is the version specified and installed in the 'pygments' tox env.
+# In any environment where the PYGMENTS_VERSION environment variable is either not defined or doesn't
+# match the version of Pygments installed, all tests which rely in pygments will be skipped.
+required_pygments_version = os.environ.get('PYGMENTS_VERSION', '')
+
 
 class TestCodeHiliteClass(TestCase):
     """ Test the markdown.extensions.codehilite.CodeHilite class. """
 
+    def setUp(self):
+        if has_pygments and pygments.__version__ != required_pygments_version:
+            self.skipTest(f'Pygments=={required_pygments_version} is required')
+
     maxDiff = None
 
     def assertOutputEquals(self, source, expected, **options):
@@ -205,7 +215,7 @@ class TestCodeHiliteClass(TestCase):
     def test_codehilite_linenos_inline(self):
         if has_pygments:
             expected = (
-                '<div class="codehilite"><pre><span></span><code><span class="lineno">1 </span>plain text\n'
+                '<div class="codehilite"><pre><span></span><code><span class="linenos">1</span>plain text\n'
                 '</code></pre></div>'
             )
         else:
@@ -259,7 +269,7 @@ class TestCodeHiliteClass(TestCase):
     def test_codehilite_linenostart(self):
         if has_pygments:
             expected = (
-                '<div class="codehilite"><pre><span></span><code><span class="lineno">42 </span>plain text\n'
+                '<div class="codehilite"><pre><span></span><code><span class="linenos">42</span>plain text\n'
                 '</code></pre></div>'
             )
         else:
@@ -274,9 +284,9 @@ class TestCodeHiliteClass(TestCase):
         if has_pygments:
             expected = (
                 '<div class="codehilite"><pre><span></span><code>'
-                '<span class="lineno">1 </span><span class="hll">line 1\n'
-                '</span><span class="lineno">2 </span>line 2\n'
-                '<span class="lineno">3 </span><span class="hll">line 3\n'
+                '<span class="linenos">1</span><span class="hll">line 1\n'
+                '</span><span class="linenos">2</span>line 2\n'
+                '<span class="linenos">3</span><span class="hll">line 3\n'
                 '</span></code></pre></div>'
             )
         else:
@@ -291,9 +301,9 @@ class TestCodeHiliteClass(TestCase):
     def test_codehilite_linenos_linenostep(self):
         if has_pygments:
             expected = (
-                '<div class="codehilite"><pre><span></span><code><span class="lineno">  </span>line 1\n'
-                '<span class="lineno">2 </span>line 2\n'
-                '<span class="lineno">  </span>line 3\n'
+                '<div class="codehilite"><pre><span></span><code><span class="linenos"> </span>line 1\n'
+                '<span class="linenos">2</span>line 2\n'
+                '<span class="linenos"> </span>line 3\n'
                 '</code></pre></div>'
             )
         else:
@@ -308,9 +318,9 @@ class TestCodeHiliteClass(TestCase):
     def test_codehilite_linenos_linenospecial(self):
         if has_pygments:
             expected = (
-                '<div class="codehilite"><pre><span></span><code><span class="lineno">1 </span>line 1\n'
-                '<span class="lineno special">2 </span>line 2\n'
-                '<span class="lineno">3 </span>line 3\n'
+                '<div class="codehilite"><pre><span></span><code><span class="linenos">1</span>line 1\n'
+                '<span class="linenos special">2</span>line 2\n'
+                '<span class="linenos">3</span>line 3\n'
                 '</code></pre></div>'
             )
         else:
@@ -340,6 +350,10 @@ class TestCodeHiliteClass(TestCase):
 class TestCodeHiliteExtension(TestCase):
     """ Test codehilite extension. """
 
+    def setUp(self):
+        if has_pygments and pygments.__version__ != required_pygments_version:
+            self.skipTest(f'Pygments=={required_pygments_version} is required')
+
     maxDiff = None
 
     def testBasicCodeHilite(self):
@@ -630,3 +644,35 @@ class TestCodeHiliteExtension(TestCase):
             expected,
             extensions=[CodeHiliteExtension(unknown='some value')],
         )
+
+    def testMultipleBlocksSameStyle(self):
+        if has_pygments:
+            # See also: https://github.com/Python-Markdown/markdown/issues/1240
+            expected = (
+                '<div class="codehilite" style="background: #202020"><pre style="line-height: 125%; margin: 0;">'
+                '<span></span><code><span style="color: #999999; font-style: italic"># First Code Block</span>\n'
+                '</code></pre></div>\n\n'
+                '<p>Normal paragraph</p>\n'
+                '<div class="codehilite" style="background: #202020"><pre style="line-height: 125%; margin: 0;">'
+                '<span></span><code><span style="color: #999999; font-style: italic"># Second Code Block</span>\n'
+                '</code></pre></div>'
+            )
+        else:
+            expected = (
+                '<pre class="codehilite"><code class="language-python"># First Code Block\n'
+                '</code></pre>\n\n'
+                '<p>Normal paragraph</p>\n'
+                '<pre class="codehilite"><code class="language-python"># Second Code Block\n'
+                '</code></pre>'
+            )
+        self.assertMarkdownRenders(
+            (
+                '\t:::Python\n'
+                '\t# First Code Block\n\n'
+                'Normal paragraph\n\n'
+                '\t:::Python\n'
+                '\t# Second Code Block'
+            ),
+            expected,
+            extensions=[CodeHiliteExtension(pygments_style="native", noclasses=True)]
+        )
